==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/components/camel-test/camel-test-spring-junit5/src/main/java/org/apache/camel/test/spring/junit5/ExcludeRoutes.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.spring.junit5;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.apache.camel.RoutesBuilder;

/**
 * Indicates if certain route builder classes should be excluded from discovery. Initializes a
 * {@link org.apache.camel.spi.PackageScanClassResolver} to exclude a set of given classes from being resolved.
 * Typically this is used at test time to exclude certain routes, which might otherwise be noisy, from being discovered
 * and initialized.
 */
@Documented
@Inherited
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.TYPE })
public @interface ExcludeRoutes {

    /**
     * The classes to exclude from resolution when using package scanning.
     */
    Class<? extends RoutesBuilder>[] value() default {};
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-test/camel-test-spring-junit5/src/main/java/org/apache/camel/test/spring/junit5/ExcludeRoutes.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.spring.junit5;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.apache.camel.RoutesBuilder;

/**
 * Indicates if certain route builder classes should be excluded from discovery. Initializes a
 * {@link org.apache.camel.spi.PackageScanClassResolver} to exclude a set of given classes from being resolved.
 * Typically, this is used at test time to exclude certain routes, which might otherwise be noisy, from being discovered
 * and initialized.
 */
@Documented
@Inherited
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.TYPE })
public @interface ExcludeRoutes {

    /**
     * The classes to exclude from resolution when using package scanning.
     */
    Class<? extends RoutesBuilder>[] value() default {};
}
